@@ -12,9 +12,10 @@ from aquiles.configs import load_aquiles_config, save_aquiles_configs
 from aquiles.connection import get_connectionAll
 from aquiles.schemas import RedsSch
 from aquiles.wrapper import RdsWr, QdrantWr, PostgreSQLRAG
-from aquiles.models import QueryRAG, SendRAG, CreateIndex, DropIndex, EditsConfigsReds, EditsConfigsQdrant
+from aquiles.models import QueryRAG, SendRAG, CreateIndex, DropIndex, EditsConfigsReds, EditsConfigsQdrant, EditsConfigsPostgreSQL
 from aquiles.utils import verify_api_key
 from aquiles.auth import authenticate_user, create_access_token, ACCESS_TOKEN_EXPIRE_MINUTES, get_current_user
+from aquiles.rerank import api
 from starlette.status import HTTP_500_INTERNAL_SERVER_ERROR, HTTP_401_UNAUTHORIZED
 import os
 import pathlib
@@ -31,6 +32,27 @@ async def lifespan(app: FastAPI):
     app.state.aquiles_config = await load_aquiles_config()
 
     type_co = app.state.aquiles_config.get("type_co", app.state.aquiles_config.get("type_c", "Redis"))
+
+    try:
+        configs = app.state.aquiles_config
+        if configs.get("rerank", False):
+            from aquiles.rerank import Reranker as RerankerClass
+            import asyncio  
+            provider = configs.get("provider_re", None)
+            model = configs.get("reranker_model", "Xenova/ms-marco-MiniLM-L-6-v2")
+            max_re = configs.get("max_concurrent_request", 2)
+            providers = provider if isinstance(provider, list) else ([provider] if provider else None)
+            app.state.reranker = RerankerClass(model_name=model, providers=providers, max_concurrent=max_re)
+
+            if configs.get("reranker_preload", False):
+                asyncio.create_task(app.state.reranker.load_async())
+                print("Reranker preload scheduled (background).")
+        else:
+            app.state.reranker = None
+            print("Reranker disabled by config.")
+    except Exception as e:
+        print("Warning: failed to prepare reranker singleton:", e)
+        app.state.reranker = None
     
     try:
         yield
@@ -64,7 +86,7 @@ async def lifespan(app: FastAPI):
                     else:
                         con.close()
         except Exception:
-            print("Error cerrando la conexión en shutdown")
+            print("Error closing the connection on shutdown")
 
 app = FastAPI(title="Aquiles-RAG", debug=True, lifespan=lifespan, docs_url=None, redoc_url=None)
 
@@ -74,8 +96,9 @@ templates_dir = os.path.join(package_dir, "templates")
 templates = Jinja2Templates(directory=templates_dir)
 app.mount("/static", StaticFiles(directory=static_dir), name="static")
 
+app.include_router(api.router)
 
-@app.post("/create/index", dependencies=[Depends(verify_api_key)])
+@app.post("/create/index", dependencies=[Depends(verify_api_key)], tags=["RAG APIs"])
 async def create_index(q: CreateIndex, request: Request):
     conf = getattr(request.app.state, "aquiles_config", {}) or {}
     type_co = conf.get("type_c", "Redis")
@@ -137,7 +160,7 @@ async def create_index(q: CreateIndex, request: Request):
             "status": "success",
             "index": q.indexname}   
 
-@app.post("/rag/create", dependencies=[Depends(verify_api_key)])
+@app.post("/rag/create", dependencies=[Depends(verify_api_key)], tags=["RAG APIs"])
 async def send_rag(q: SendRAG, request: Request):
 
     conf = getattr(request.app.state, "aquiles_config", {}) or {}
@@ -196,7 +219,7 @@ async def send_rag(q: SendRAG, request: Request):
         return {"status": "ok", "key": key}
 
 
-@app.post("/rag/query-rag", dependencies=[Depends(verify_api_key)])
+@app.post("/rag/query-rag", dependencies=[Depends(verify_api_key)], tags=["RAG APIs"])
 async def query_rag(q: QueryRAG, request: Request):
 
     conf = getattr(request.app.state, "aquiles_config", {}) or {}
@@ -204,8 +227,6 @@ async def query_rag(q: QueryRAG, request: Request):
     r = request.app.state.con
     
     if type_co == "Redis":
-
-
         if q.dtype == "FLOAT32":
             dtype = np.float32
         elif q.dtype == "FLOAT16":
@@ -239,7 +260,7 @@ async def query_rag(q: QueryRAG, request: Request):
         return {"status": "ok", "total": len(results), "results": results}
 
 
-@app.post("/rag/drop_index", dependencies=[Depends(verify_api_key)])
+@app.post("/rag/drop_index", dependencies=[Depends(verify_api_key)], tags=["RAG APIs"])
 async def drop_index(q: DropIndex, request: Request):
 
     conf = getattr(request.app.state, "aquiles_config", {}) or {}
@@ -284,7 +305,7 @@ async def auth_exception_handler(request: Request, exc: HTTPException):
     return JSONResponse(status_code=exc.status_code, content={"detail": exc.detail})
 
 
-@app.post("/token")
+@app.post("/token", tags=["HTML Helper"])
 async def login_for_access_token(form_data: OAuth2PasswordRequestForm = Depends()):
     if not await authenticate_user(form_data.username, form_data.password):
         raise HTTPException(status_code=HTTP_401_UNAUTHORIZED,
@@ -297,8 +318,8 @@ async def login_for_access_token(form_data: OAuth2PasswordRequestForm = Depends(
     response.set_cookie(key="access_token", value=f"Bearer {token}", httponly=True)
     return response
 
-@app.get("/")
-@app.get("/ui", response_class=HTMLResponse)
+@app.get("/", tags=["HTML"])
+@app.get("/ui", response_class=HTMLResponse, tags=["HTML"])
 async def home(request: Request, user: str = Depends(get_current_user)):
     try:
         conf = getattr(request.app.state, "aquiles_config", {}) or {}
@@ -307,11 +328,11 @@ async def home(request: Request, user: str = Depends(get_current_user)):
     except HTTPException:
         return RedirectResponse(url="/login/ui", status_code=302)
 
-@app.get("/login/ui", response_class=HTMLResponse)
+@app.get("/login/ui", response_class=HTMLResponse, tags=["HTML"])
 async def login_ui(request: Request):
     return templates.TemplateResponse("login_ui.html", {"request": request})
 
-@app.get("/ui/configs")
+@app.get("/ui/configs", tags=["HTML Helper"])
 async def get_configs(request: Request, user: str = Depends(get_current_user)):
     try:
         indices = []
@@ -362,14 +383,33 @@ async def get_configs(request: Request, user: str = Depends(get_current_user)):
                     "indices": indices
                     }
 
+        elif type_co == "PostgreSQL":
+            clientPg = PostgreSQLRAG(r)
+
+            indices = await clientPg.get_ind()
+
+            dict_ = {"local": conf["local"],
+                    "host": conf["host"],
+                    "port": conf["port"],
+                    "user": conf["user"],
+                    "password": conf["password"],
+                    "min_size": conf["min_size"],
+                    "max_size": conf["max_size"],
+                    "max_queries": conf["max_queries"],
+                    "timeout": conf["timeout"],
+                    "allows_api_keys": conf["allows_api_keys"],
+                    "allows_users": conf["allows_users"],
+                    "indices": indices
+                    }
+
             
         return dict_
 
     except HTTPException:
         return RedirectResponse(url="/login/ui", status_code=302)
 
-@app.post("/ui/configs")
-async def ui_configs(update: Union[EditsConfigsReds, EditsConfigsQdrant], user: str = Depends(get_current_user)):
+@app.post("/ui/configs", tags=["HTML Helper"])
+async def ui_configs(update: Union[EditsConfigsReds, EditsConfigsQdrant, EditsConfigsPostgreSQL], user: str = Depends(get_current_user)):
     try:
         configs = app.state.aquiles_config
 
@@ -408,7 +448,7 @@ async def protected_redoc_ui(request: Request, user: str = Depends(get_current_u
         title=f"{app.title} – ReDoc",
     )
 
-@app.get("/status/ram")
+@app.get("/status/ram", tags=["HTML Helper"])
 async def get_status_ram(request: Request) -> Dict[str, Any]:
 
     conf = getattr(request.app.state, "aquiles_config", {}) or {}
@@ -445,7 +485,7 @@ async def get_status_ram(request: Request) -> Dict[str, Any]:
         "app_process": app_metrics,
     }
 
-@app.get("/status", response_class=HTMLResponse)
+@app.get("/status", response_class=HTMLResponse, tags=["HTML"])
 async def status(request: Request):
     return templates.TemplateResponse("status.html", {"request": request})
 
@@ -474,6 +514,14 @@ async def readiness(request: Request):
         except:
             raise HTTPException(503, "Qdrant unavailable")
 
+    elif type_co == "PostgreSQL":
+        try:
+            clientPg = PostgreSQLRAG(r)
+
+            await clientPg.ready()
+        except:
+            raise HTTPException(503, "PostgreSQL unavailable")
+
     return {"status": "ready"}
 
 app.add_middleware(
